@@ -17,10 +17,12 @@
 #
 
 ###
-# This is an example from the Inventor Mentor,
-# chapter 2, example 4.
+# This is an example from the Inventor Mentor
+# chapter 16, example 5.
 #
-# Use the Examiner Viewer to look at a red cone
+# This example creates a simple scene graph and attaches a
+# browser Examiner viewer to view the data. The camera and
+# light in the scene are automatically created by the viewer.
 #
 
 import sys
@@ -29,22 +31,28 @@ from pivy.coin import *
 from pivy.sogui import *
 
 def main():
+    # Initialize Inventor and Qt
     myWindow = SoGui.init(sys.argv[0])
-    if myWindow == None: sys.exit(1)
-
-    root = SoSeparator()
-    myMaterial = SoMaterial()
-    myMaterial.diffuseColor = (1.0, 0.0, 0.0)
-    root.addChild(myMaterial)
-    root.addChild(SoCone())
-
-    # Set up viewer:
+   
+    # Build the viewer in the applications main window
     myViewer = SoGuiExaminerViewer(myWindow)
-    myViewer.setSceneGraph(root)
-    myViewer.setTitle("Examiner Viewer")
+   
+    # Read the geometry from a file and add to the scene
+    myInput = SoInput()
+    if not myInput.openFile("dogDish.iv"):
+        sys.exit(1)
+    geomObject = SoDB.readAll(myInput)
+    if geomObject == None:
+        sys.exit(1)
+   
+    # Attach the viewer to the scene graph
+    myViewer.setSceneGraph(geomObject)
+   
+    # Show the main window
     myViewer.show()
-
     SoGui.show(myWindow)
+
+    # Loop forever
     SoGui.mainLoop()
 
 if __name__ == "__main__":
