@@ -1,6 +1,6 @@
 from __future__ import print_function
 import unittest
-from PySide2 import QtCore
+from pivy.qt import QtCore
 import shiboken2 as wrapper
 
 
